package Net::Braintree::Test::MerchantAccount;
use strict;

use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS );
use Exporter qw(import);
our @ISA = qw(Exporter);

use constant Approve => "approve_me";

1;
