package Net::Braintree::ErrorCodes::Transaction::Options;
use strict;

use constant SubmitForSettlementIsRequiredForCloning => "91544";
use constant VaultIsDisabled                         => "91525";

1;

